'use strict';

exports.__esModule = true;
exports.FormContext = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Fields = function () {
  function Fields() {
    var _this = this;

    (0, _classCallCheck3.default)(this, Fields);

    this.getFieldsOptions = function () {
      return _this.__getFieldsOptions__REACT_HOT_LOADER__.apply(_this, arguments);
    };

    this.getValues = function () {
      return _this.__getValues__REACT_HOT_LOADER__.apply(_this, arguments);
    };

    this.clear();
  }

  Fields.prototype.getFields = function getFields() {
    return this.fields;
  };

  Fields.prototype.getFieldByName = function getFieldByName(name) {
    return this.getFields()[name];
  };

  Fields.prototype.getFieldOptions = function getFieldOptions(name) {
    var field = this.getFieldByName(name);
    if (field) {
      return field.getFieldOptions();
    }
  };

  Fields.prototype.__getFieldsOptions__REACT_HOT_LOADER__ = function __getFieldsOptions__REACT_HOT_LOADER__() {
    var _this2 = this;

    return (0, _lodash.keyBy)((0, _lodash.map)(this.getFields(), function (field) {
      return _this2.getFieldOptions(field.name);
    }), 'name');
  };

  Fields.prototype.__getValues__REACT_HOT_LOADER__ = function __getValues__REACT_HOT_LOADER__() {
    var values = {};
    (0, _lodash.forEach)(this.getFieldsOptions(), function (field) {
      values[field.name] = field.value;
    });
    return values;
  };

  Fields.prototype.updateField = function updateField(field) {
    this.fields[field.name] = field;
  };

  Fields.prototype.isValid = function isValid() {
    var fields = this.getFieldsOptions();
    var isValid = true;
    (0, _lodash.forEach)(fields, function (field) {
      if (field.pending) {
        isValid = false;
      }
      if (field.errors.length || field.asyncErrors.length) {
        isValid = false;
      }
    });
    return isValid;
  };

  Fields.prototype.updateFieldsAsUsed = function updateFieldsAsUsed() {
    (0, _lodash.forEach)(this.getFields(), function (field) {
      field.instance.validate();
    });
  };

  Fields.prototype.reset = function reset() {
    var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var promises = [];
    (0, _lodash.forEach)(this.getFields(), function (field, key) {
      promises.push(field.instance.reset(value[key]));
    });
    return _promise2.default.all(promises);
  };

  Fields.prototype.removeField = function removeField(name) {
    delete this.fields[name];
  };

  Fields.prototype.subscribe = function subscribe(f, name) {
    var subscriber = {
      callback: f,
      id: ++this.lastId
    };
    if (this.subscribers[name]) {
      this.subscribers[name].push(subscriber);
    } else {
      this.subscribers[name] = [subscriber];
    }
    this.publish(name);
    return this.lastId;
  };

  Fields.prototype.publish = function publish(name) {
    var _this3 = this;

    if (this.subscribers[name]) {
      this.subscribers[name].forEach(function (subscriber) {
        if (name) {
          subscriber.callback(_this3.getFieldOptions(name));
        } else {
          subscriber.callback(_this3.getFieldsOptions());
        }
      });
    }
  };

  Fields.prototype.removeSubscriber = function removeSubscriber(id) {
    if (!id) {
      return null;
    }
    (0, _lodash.forEach)(this.subscribers, function (subscribers) {
      for (var i = subscribers.length - 1; i >= 0; i--) {
        if (subscribers[i].id === id) {
          subscribers.splice(i, 1);
          return true;
        }
      }
    });
  };

  Fields.prototype.clear = function clear() {
    this.subscribers = {};
    this.fields = {};
    this.lastId = 0;
  };

  return Fields;
}();

var Validators = function () {
  function Validators() {
    (0, _classCallCheck3.default)(this, Validators);

    this.clear();
  }

  Validators.prototype.updateFields = function updateFields() {
    var fields = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    this.fields = fields;
  };

  Validators.prototype.updateValidators = function updateValidators(validators) {
    this.validators = validators;
    this.errors = this.getErrors();
  };

  Validators.prototype.getErrors = function getErrors() {
    var _this4 = this;

    var errors = {};
    (0, _lodash.forEach)(this.validators, function (validator, name) {
      errors[name] = validator(_this4.fields);
    });
    this.errors = errors;
    return errors;
  };

  Validators.prototype.isValid = function isValid() {
    var errors = this.getErrors();
    return !(0, _lodash.some)(errors, function (v) {
      return !!v;
    });
  };

  Validators.prototype.subscribe = function subscribe(f, name) {
    var subscriber = {
      callback: f,
      id: ++this.lastId
    };
    var sName = name || '__all__';
    if (this.subscribers[sName]) {
      this.subscribers[sName].push(subscriber);
    } else {
      this.subscribers[sName] = [subscriber];
    }
    return this.lastId;
  };

  Validators.prototype.publish = function publish() {
    var _this5 = this;

    var errors = this.getErrors();
    (0, _lodash.forEach)(errors, function (error, name) {
      if (name !== '__all__') {
        var _subscribers = _this5.subscribers[name] || [];
        _subscribers.forEach(function (subscriber) {
          subscriber.callback(error);
        });
      }
    });

    var subscribers = this.subscribers['__all__'] || [];
    subscribers.forEach(function (subscriber) {
      subscriber.callback(errors);
    });
  };

  Validators.prototype.removeSubscriber = function removeSubscriber(id) {
    if (!id) {
      return null;
    }
    (0, _lodash.forEach)(this.subscribers, function (subscribers) {
      for (var i = subscribers.length - 1; i >= 0; i--) {
        if (subscribers[i].id === id) {
          subscribers.splice(i, 1);
          return true;
        }
      }
    });
  };

  Validators.prototype.clear = function clear() {
    this.subscribers = {};
    this.validators = {};
    this.fields = {};
    this.errors = {};
    this.lastId = 0;
  };

  return Validators;
}();

var FormContext = exports.FormContext = function () {
  function FormContext() {
    (0, _classCallCheck3.default)(this, FormContext);

    this.initialized = false;
    this.fields = new Fields();
    this.validators = new Validators();
    this.errors = [];
    this.formValidators = {};
    this.formValidatorsOptions = {};
    this.formAsyncValidator = {};
    this.formAsyncValidatorOptions = {};
  }

  FormContext.prototype.update = function update() {
    this.validators.updateFields(this.fields.getFieldsOptions());
    this.validators.updateValidators(this.formValidators['']);
    this.validators.publish();
  };

  FormContext.prototype.onInitField = function onInitField(field) {
    this.fields.updateField(field);
    this.fields.publish(field.name);
    this.fields.publish('');
    if (this.initialized) {
      this.update();
    }
  };

  FormContext.prototype.onUpdateField = function onUpdateField(field) {
    this.fields.updateField(field);
    this.fields.publish(field.name);
    this.fields.publish('');
    this.update();
  };

  FormContext.prototype.onRemoveField = function onRemoveField(field) {
    this.fields.removeField(field.name);
    this.update();
  };

  FormContext.prototype.setValidators = function setValidators() {
    var validators = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    this.formValidators = validators;
  };

  FormContext.prototype.setValidatorsOptions = function setValidatorsOptions() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    this.formValidatorsOptions = options;
  };

  FormContext.prototype.setAsyncValidator = function setAsyncValidator() {
    var validators = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    this.formAsyncValidator = validators;
  };

  FormContext.prototype.setAsyncValidatorOptions = function setAsyncValidatorOptions() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    this.formAsyncValidatorOptions = options;
  };

  FormContext.prototype.isValid = function isValid() {
    return this.validators.isValid() && this.fields.isValid();
  };

  FormContext.prototype.reset = function reset(value) {
    var _this6 = this;

    this.initialized = false;
    this.fields.reset(value).then(function () {
      _this6.initialized = true;
      _this6.update();
    });
  };

  FormContext.prototype.clear = function clear() {
    this.setValidators();
    this.setValidatorsOptions();
    this.setAsyncValidator();
    this.setAsyncValidatorOptions();
    this.fields.clear();
    this.validators.clear();
  };

  return FormContext;
}();

;

var _temp = function () {
  if (typeof __REACT_HOT_LOADER__ === 'undefined') {
    return;
  }

  __REACT_HOT_LOADER__.register(Fields, 'Fields', 'E:/Projects/React/git/vb-react-form/src/form-context.js');

  __REACT_HOT_LOADER__.register(Validators, 'Validators', 'E:/Projects/React/git/vb-react-form/src/form-context.js');

  __REACT_HOT_LOADER__.register(FormContext, 'FormContext', 'E:/Projects/React/git/vb-react-form/src/form-context.js');
}();

;