'use strict';

exports.__esModule = true;
exports.MaxValueValidator = exports.MinValueValidator = exports.NumberValidator = exports.MaxLengthValidator = exports.MinLengthValidator = exports.PasswordValidator = exports.CurrencyValidator = exports.PhoneValidator = exports.WebSiteValidator = exports.EmailValidator = exports.RequiredValidator = exports.RegexValidator = exports.EqualValidator = exports.Validator = undefined;

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _validator = require('validator');

var _validator2 = _interopRequireDefault(_validator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Validator = exports.Validator = function () {
  function Validator(message) {
    (0, _classCallCheck3.default)(this, Validator);

    this.name = this.constructor.name;
    this.message = message;
  }

  Validator.prototype.convertValue = function convertValue(value) {
    return value && value.toString() || '';
  };

  Validator.prototype.isValid = function isValid(value) {
    return true;
  };

  Validator.prototype.isInvalid = function isInvalid(value) {
    return !this.isValid(value);
  };

  Validator.prototype.error = function error(name, value) {
    return this.message || 'Wrong value';
  };

  return Validator;
}();

var EqualValidator = exports.EqualValidator = function (_Validator) {
  (0, _inherits3.default)(EqualValidator, _Validator);

  function EqualValidator(value, message) {
    (0, _classCallCheck3.default)(this, EqualValidator);

    var _this = (0, _possibleConstructorReturn3.default)(this, _Validator.call(this, message));

    _this.value = value;
    return _this;
  }

  EqualValidator.prototype.isValid = function isValid(value) {
    return value === this.value;
  };

  EqualValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is not equal.';
  };

  return EqualValidator;
}(Validator);

var RegexValidator = exports.RegexValidator = function (_Validator2) {
  (0, _inherits3.default)(RegexValidator, _Validator2);

  function RegexValidator(regex, message) {
    (0, _classCallCheck3.default)(this, RegexValidator);

    var _this2 = (0, _possibleConstructorReturn3.default)(this, _Validator2.call(this, message));

    _this2.regex = new RegExp(regex);
    return _this2;
  }

  RegexValidator.prototype.isValid = function isValid(value) {
    return this.regex.test(value);
  };

  RegexValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is not valid.';
  };

  return RegexValidator;
}(Validator);

var RequiredValidator = exports.RequiredValidator = function (_Validator3) {
  (0, _inherits3.default)(RequiredValidator, _Validator3);

  function RequiredValidator() {
    (0, _classCallCheck3.default)(this, RequiredValidator);
    return (0, _possibleConstructorReturn3.default)(this, _Validator3.apply(this, arguments));
  }

  RequiredValidator.prototype.isValid = function isValid(value) {
    return !_validator2.default.isEmpty(this.convertValue(value));
  };

  RequiredValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is required.';
  };

  return RequiredValidator;
}(Validator);

var EmailValidator = exports.EmailValidator = function (_Validator4) {
  (0, _inherits3.default)(EmailValidator, _Validator4);

  function EmailValidator() {
    (0, _classCallCheck3.default)(this, EmailValidator);
    return (0, _possibleConstructorReturn3.default)(this, _Validator4.apply(this, arguments));
  }

  EmailValidator.prototype.isValid = function isValid(value) {
    return _validator2.default.isEmail(this.convertValue(value));
  };

  EmailValidator.prototype.error = function error(name, value) {
    return this.message || 'This value should be a valid email.';
  };

  return EmailValidator;
}(Validator);

var WebSiteValidator = exports.WebSiteValidator = function (_Validator5) {
  (0, _inherits3.default)(WebSiteValidator, _Validator5);

  function WebSiteValidator() {
    (0, _classCallCheck3.default)(this, WebSiteValidator);
    return (0, _possibleConstructorReturn3.default)(this, _Validator5.apply(this, arguments));
  }

  WebSiteValidator.prototype.isValid = function isValid(value) {
    return _validator2.default.isURL(this.convertValue(value));
  };

  WebSiteValidator.prototype.error = function error(name, value) {
    return this.message || 'This value should be a valid website.';
  };

  return WebSiteValidator;
}(Validator);

var PhoneValidator = exports.PhoneValidator = function (_Validator6) {
  (0, _inherits3.default)(PhoneValidator, _Validator6);

  function PhoneValidator(locale, message) {
    (0, _classCallCheck3.default)(this, PhoneValidator);

    var _this6 = (0, _possibleConstructorReturn3.default)(this, _Validator6.call(this, message));

    _this6.locale = locale;
    return _this6;
  }

  PhoneValidator.prototype.isValid = function isValid(value) {
    return _validator2.default.isMobilePhone(this.convertValue(value), this.locale);
  };

  PhoneValidator.prototype.error = function error(name, value) {
    return this.message || 'This value should be a valid phone number.';
  };

  return PhoneValidator;
}(Validator);

var CurrencyValidator = exports.CurrencyValidator = function (_Validator7) {
  (0, _inherits3.default)(CurrencyValidator, _Validator7);

  function CurrencyValidator() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : { allow_negatives: false };
    var message = arguments[1];
    (0, _classCallCheck3.default)(this, CurrencyValidator);

    var _this7 = (0, _possibleConstructorReturn3.default)(this, _Validator7.call(this, message));

    _this7.options = options;
    return _this7;
  }

  CurrencyValidator.prototype.isValid = function isValid(value) {
    return _validator2.default.isCurrency(this.convertValue(value), this.options);
  };

  CurrencyValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is not currency amount.';
  };

  return CurrencyValidator;
}(Validator);

var PasswordValidator = exports.PasswordValidator = function (_RegexValidator) {
  (0, _inherits3.default)(PasswordValidator, _RegexValidator);

  function PasswordValidator() {
    var strong = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
    var message = arguments[1];
    (0, _classCallCheck3.default)(this, PasswordValidator);

    var _this8 = (0, _possibleConstructorReturn3.default)(this, _RegexValidator.call(this, strong ? PasswordValidator.strongRegex : PasswordValidator.mediumRegex, message));

    _this8.strong = strong;
    return _this8;
  }

  PasswordValidator.prototype.error = function error(name, value) {
    if (this.strong) {
      return 'The string must contain at least 1 lowercase alphabetical character, ' + 'at least 1 uppercase alphabetical character, ' + 'at least 1 numeric character and ' + 'at least one special character';
    }
    return 'The string must contain at least 1 lowercase or uppercase alphabetical character and ' + 'at least 1 numeric character';
  };

  return PasswordValidator;
}(RegexValidator);

PasswordValidator.strongRegex = '^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[!@#\$%\^&\*])';
PasswordValidator.mediumRegex = '^((?=.*[a-z])(?=.*[A-Z]))|((?=.*[a-z])(?=.*[0-9]))|((?=.*[A-Z])(?=.*[0-9]))';

var MinLengthValidator = exports.MinLengthValidator = function (_Validator8) {
  (0, _inherits3.default)(MinLengthValidator, _Validator8);

  function MinLengthValidator(minLength, message) {
    (0, _classCallCheck3.default)(this, MinLengthValidator);

    var _this9 = (0, _possibleConstructorReturn3.default)(this, _Validator8.call(this, message));

    _this9.minLength = minLength;
    return _this9;
  }

  MinLengthValidator.prototype.isValid = function isValid(value) {
    return _validator2.default.isLength(this.convertValue(value), { min: this.minLength });
  };

  MinLengthValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is too short. It should have ' + this.minLength + ' characters or more.';
  };

  return MinLengthValidator;
}(Validator);

var MaxLengthValidator = exports.MaxLengthValidator = function (_Validator9) {
  (0, _inherits3.default)(MaxLengthValidator, _Validator9);

  function MaxLengthValidator(maxLength, message) {
    (0, _classCallCheck3.default)(this, MaxLengthValidator);

    var _this10 = (0, _possibleConstructorReturn3.default)(this, _Validator9.call(this, message));

    _this10.maxLength = maxLength;
    return _this10;
  }

  MaxLengthValidator.prototype.isValid = function isValid(value) {
    return _validator2.default.isLength(this.convertValue(value), { max: this.maxLength });
  };

  MaxLengthValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is too long. It should have ' + this.maxLength + ' characters or less.';
  };

  return MaxLengthValidator;
}(Validator);

var NumberValidator = exports.NumberValidator = function (_Validator10) {
  (0, _inherits3.default)(NumberValidator, _Validator10);

  function NumberValidator() {
    (0, _classCallCheck3.default)(this, NumberValidator);
    return (0, _possibleConstructorReturn3.default)(this, _Validator10.apply(this, arguments));
  }

  NumberValidator.prototype.isValid = function isValid(value) {
    return _validator2.default.isInt(this.convertValue(value)) || _validator2.default.isFloat(this.convertValue(value));
  };

  NumberValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is not a number.';
  };

  return NumberValidator;
}(Validator);

var MinValueValidator = exports.MinValueValidator = function (_NumberValidator) {
  (0, _inherits3.default)(MinValueValidator, _NumberValidator);

  function MinValueValidator(minValue, message) {
    (0, _classCallCheck3.default)(this, MinValueValidator);

    var _this12 = (0, _possibleConstructorReturn3.default)(this, _NumberValidator.call(this, message));

    _this12.minValue = minValue;
    return _this12;
  }

  MinValueValidator.prototype.isValid = function isValid(value) {
    return _NumberValidator.prototype.isValid.call(this, value) && value >= this.minValue;
  };

  MinValueValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is too small. It should be ' + this.minValue + ' or more.';
  };

  return MinValueValidator;
}(NumberValidator);

var MaxValueValidator = exports.MaxValueValidator = function (_NumberValidator2) {
  (0, _inherits3.default)(MaxValueValidator, _NumberValidator2);

  function MaxValueValidator(maxValue, message) {
    (0, _classCallCheck3.default)(this, MaxValueValidator);

    var _this13 = (0, _possibleConstructorReturn3.default)(this, _NumberValidator2.call(this, message));

    _this13.maxValue = maxValue;
    return _this13;
  }

  MaxValueValidator.prototype.isValid = function isValid(value) {
    return _NumberValidator2.prototype.isValid.call(this, value) && value <= this.maxValue;
  };

  MaxValueValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is too big. It should be ' + this.maxValue + ' or less.';
  };

  return MaxValueValidator;
}(NumberValidator);

;

var _temp = function () {
  if (typeof __REACT_HOT_LOADER__ === 'undefined') {
    return;
  }

  __REACT_HOT_LOADER__.register(Validator, 'Validator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(EqualValidator, 'EqualValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(RegexValidator, 'RegexValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(RequiredValidator, 'RequiredValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(EmailValidator, 'EmailValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(WebSiteValidator, 'WebSiteValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(PhoneValidator, 'PhoneValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(CurrencyValidator, 'CurrencyValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(PasswordValidator, 'PasswordValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(MinLengthValidator, 'MinLengthValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(MaxLengthValidator, 'MaxLengthValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(NumberValidator, 'NumberValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(MinValueValidator, 'MinValueValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');

  __REACT_HOT_LOADER__.register(MaxValueValidator, 'MaxValueValidator', 'E:/Projects/React/git/vb-react-form/src/validators.js');
}();

;